@@ -1,5 +1,6 @@
 from .app import IdfApp
 from .dut import IdfDut
+from .linux import LinuxDut, LinuxSerial
 from .serial import IdfSerial
 from .unity_tester import CaseTester
 
@@ -8,4 +9,6 @@ __all__ = [
     'IdfSerial',
     'IdfDut',
     'CaseTester',
+    'LinuxSerial',
+    'LinuxDut',
 ]
